Home
last modified time | relevance | path

Searched refs:__size (Results 1 – 25 of 136) sorted by relevance

123456

/netbsd-src/external/gpl3/gcc.old/dist/libstdc++-v3/include/bits/
H A Dstring_view.tcc107 size_type __size = this->_M_len; in rfind() local
108 if (__size > 0) in rfind()
110 if (--__size > __pos) in rfind()
111 __size = __pos; in rfind()
112 for (++__size; __size-- > 0; ) in rfind()
113 if (traits_type::eq(this->_M_str[__size], __c)) in rfind()
114 return __size; in rfind()
143 size_type __size = this->size(); in find_last_of() local
144 if (__size && __n) in find_last_of()
146 if (--__size > __pos) in find_last_of()
[all …]
H A Dbasic_string.tcc350 const size_type __size = this->size(); in resize() local
351 if (__size < __n) in resize()
352 this->append(__n - __size, __c); in resize()
353 else if (__n < __size) in resize()
771 const size_type __size = __str.size();
772 if (__size)
774 const size_type __len = __size + this->size();
777 _M_copy(_M_data() + this->size(), __str._M_data(), __size);
843 const size_type __size = __last - __first;
844 if (__size)
[all …]
/netbsd-src/external/gpl3/gcc.old/dist/libstdc++-v3/include/experimental/bits/
H A Dstring_view.tcc111 size_type __size = this->_M_len; in rfind() local
112 if (__size > 0) in rfind()
114 if (--__size > __pos) in rfind()
115 __size = __pos; in rfind()
116 for (++__size; __size-- > 0; ) in rfind()
117 if (traits_type::eq(this->_M_str[__size], __c)) in rfind()
118 return __size; in rfind()
145 size_type __size = this->size(); in find_last_of() local
146 if (__size && __n) in find_last_of()
148 if (--__size > __pos) in find_last_of()
[all …]
/netbsd-src/external/gpl3/gcc/dist/libstdc++-v3/include/experimental/bits/
H A Dstring_view.tcc111 size_type __size = this->_M_len; in rfind() local
112 if (__size > 0) in rfind()
114 if (--__size > __pos) in rfind()
115 __size = __pos; in rfind()
116 for (++__size; __size-- > 0; ) in rfind()
117 if (traits_type::eq(this->_M_str[__size], __c)) in rfind()
118 return __size; in rfind()
145 size_type __size = this->size(); in find_last_of() local
146 if (__size && __n) in find_last_of()
148 if (--__size > __pos) in find_last_of()
[all …]
/netbsd-src/external/gpl3/gcc/dist/libstdc++-v3/include/bits/
H A Dstring_view.tcc119 size_type __size = this->_M_len; in rfind() local
120 if (__size > 0) in rfind()
122 if (--__size > __pos) in rfind()
123 __size = __pos; in rfind()
124 for (++__size; __size-- > 0; ) in rfind()
125 if (traits_type::eq(this->_M_str[__size], __c)) in rfind()
126 return __size; in rfind()
155 size_type __size = this->size(); in find_last_of() local
156 if (__size && __n) in find_last_of()
158 if (--__size > __pos) in find_last_of()
[all …]
H A Dbasic_string.tcc403 const size_type __size = this->size(); in resize() local
404 if (__size < __n) in resize()
405 this->append(__n - __size, __c); in resize()
406 else if (__n < __size) in resize()
663 const size_type __size = this->size(); in find() local
666 return __pos <= __size ? __pos : npos; in find()
667 if (__pos >= __size) in find()
673 const _CharT* const __last = __data + __size; in find()
674 size_type __len = __size - __pos; in find()
699 const size_type __size = this->size(); in find() local
[all …]
/netbsd-src/external/gpl3/gcc.old/dist/libstdc++-v3/src/c++98/
H A Distream.cc56 streamsize __size = std::min(streamsize(__sb->egptr() in getline()
60 if (__size > 1) in getline()
63 __size, in getline()
66 __size = __p - __sb->gptr(); in getline()
67 traits_type::copy(__s, __sb->gptr(), __size); in getline()
68 __s += __size; in getline()
69 __sb->__safe_gbump(__size); in getline()
70 _M_gcount += __size; in getline()
139 streamsize __size = std::min(streamsize(__sb->egptr() in ignore()
142 if (__size > 1) in ignore()
[all …]
H A Distream-string.cc74 streamsize __size = std::min(streamsize(__sb->egptr() in operator >>()
77 if (__size > 1) in operator >>()
79 __size = (__ct.scan_is(ctype_base::space, in operator >>()
81 __sb->gptr() + __size) in operator >>()
83 __str.append(__sb->gptr(), __size); in operator >>()
84 __sb->__safe_gbump(__size); in operator >>()
85 __extracted += __size; in operator >>()
151 streamsize __size = std::min(streamsize(__sb->egptr() in getline()
154 if (__size > 1) in getline()
157 __size, in getline()
[all …]
/netbsd-src/external/gpl3/gcc/dist/libstdc++-v3/src/c++98/
H A Distream.cc56 streamsize __size = std::min(streamsize(__sb->egptr() in getline()
60 if (__size > 1) in getline()
63 __size, in getline()
66 __size = __p - __sb->gptr(); in getline()
67 traits_type::copy(__s, __sb->gptr(), __size); in getline()
68 __s += __size; in getline()
69 __sb->__safe_gbump(__size); in getline()
70 _M_gcount += __size; in getline()
139 streamsize __size = std::min(streamsize(__sb->egptr() in ignore()
142 if (__size > 1) in ignore()
[all …]
H A Distream-string.cc74 streamsize __size = std::min(streamsize(__sb->egptr() in operator >>()
77 if (__size > 1) in operator >>()
79 __size = (__ct.scan_is(ctype_base::space, in operator >>()
81 __sb->gptr() + __size) in operator >>()
83 __str.append(__sb->gptr(), __size); in operator >>()
84 __sb->__safe_gbump(__size); in operator >>()
85 __extracted += __size; in operator >>()
151 streamsize __size = std::min(streamsize(__sb->egptr() in getline()
154 if (__size > 1) in getline()
157 __size, in getline()
[all …]
/netbsd-src/external/gpl3/gcc.old/dist/libstdc++-v3/include/profile/impl/
H A Dprofiler_map_to_unordered_map.h40 __log2(std::size_t __size) in __log2() argument
44 if ((2 << __bit_count) & __size) in __log2()
50 __map_insert_cost(std::size_t __size) in __map_insert_cost() argument
52 * static_cast<float>(__log2(__size))); } in __map_insert_cost()
55 __map_erase_cost(std::size_t __size) in __map_erase_cost() argument
57 * static_cast<float>(__log2(__size))); } in __map_erase_cost()
60 __map_find_cost(std::size_t __size) in __map_find_cost() argument
62 * static_cast<float>(__log2(__size))); } in __map_find_cost()
104 __record_insert(std::size_t __size, std::size_t __count) in __record_insert() argument
109 _M_map_cost += __count * __map_insert_cost(__size); in __record_insert()
[all …]
/netbsd-src/external/gpl3/gcc/dist/libstdc++-v3/include/ext/
H A Dvstring.tcc52 const size_type __size = this->size(); in resize() local
53 if (__size < __n) in resize()
54 this->append(__n - __size, __c); in resize()
55 else if (__n < __size) in resize()
56 this->_M_erase(__n, __size - __n); in resize()
273 const size_type __size = this->size(); in find() local
277 return __pos <= __size ? __pos : npos; in find()
279 if (__n <= __size) in find()
281 for (; __pos <= __size - __n; ++__pos) in find()
297 const size_type __size = this->size(); in find() local
[all …]
H A Dstdio_filebuf.h78 size_t __size = static_cast<size_t>(_GLIBCXX_BUFSIZ)); in _GLIBCXX_VISIBILITY()
91 size_t __size = static_cast<size_t>(_GLIBCXX_BUFSIZ)); in _GLIBCXX_VISIBILITY()
137 stdio_filebuf(int __fd, std::ios_base::openmode __mode, size_t __size) in _GLIBCXX_VISIBILITY()
143 this->_M_buf_size = __size; in _GLIBCXX_VISIBILITY()
154 size_t __size) in _GLIBCXX_VISIBILITY()
160 this->_M_buf_size = __size; in _GLIBCXX_VISIBILITY()
/netbsd-src/external/gpl3/gcc.old/dist/libstdc++-v3/include/ext/
H A Dvstring.tcc52 const size_type __size = this->size(); in resize() local
53 if (__size < __n) in resize()
54 this->append(__n - __size, __c); in resize()
55 else if (__n < __size) in resize()
56 this->_M_erase(__n, __size - __n); in resize()
273 const size_type __size = this->size(); in find() local
277 return __pos <= __size ? __pos : npos; in find()
279 if (__n <= __size) in find()
281 for (; __pos <= __size - __n; ++__pos) in find()
297 const size_type __size = this->size(); in find() local
[all …]
H A Dstdio_filebuf.h78 size_t __size = static_cast<size_t>(BUFSIZ)); in _GLIBCXX_VISIBILITY()
91 size_t __size = static_cast<size_t>(BUFSIZ)); in _GLIBCXX_VISIBILITY()
137 stdio_filebuf(int __fd, std::ios_base::openmode __mode, size_t __size) in _GLIBCXX_VISIBILITY()
143 this->_M_buf_size = __size; in _GLIBCXX_VISIBILITY()
154 size_t __size) in _GLIBCXX_VISIBILITY()
160 this->_M_buf_size = __size; in _GLIBCXX_VISIBILITY()
/netbsd-src/external/gpl2/libmalloc/dist/
H A Dmalloc.h99 extern __ptr_t malloc __P ((__malloc_size_t __size));
102 extern __ptr_t realloc __P ((__ptr_t __ptr, __malloc_size_t __size));
104 extern __ptr_t calloc __P ((__malloc_size_t __nmemb, __malloc_size_t __size));
110 __malloc_size_t __size));
113 extern __ptr_t valloc __P ((__malloc_size_t __size));
220 extern __ptr_t (*__morecore) __P ((__malloc_ptrdiff_t __size));
223 extern __ptr_t __default_morecore __P ((__malloc_ptrdiff_t __size));
235 extern __ptr_t (*__malloc_hook) __P ((__malloc_size_t __size));
236 extern __ptr_t (*__realloc_hook) __P ((__ptr_t __ptr, __malloc_size_t __size));
237 extern __ptr_t (*__memalign_hook) __P ((__malloc_size_t __size,
[all …]
/netbsd-src/external/apache2/llvm/dist/clang/lib/Headers/
H A Dmm_malloc.h19 extern int posix_memalign(void **__memptr, size_t __alignment, size_t __size);
25 extern "C" int posix_memalign(void **__memptr, size_t __alignment, size_t __size);
32 _mm_malloc(size_t __size, size_t __align) in _mm_malloc() argument
35 return malloc(__size); in _mm_malloc()
43 __mallocedMemory = __mingw_aligned_malloc(__size, __align); in _mm_malloc()
45 __mallocedMemory = _aligned_malloc(__size, __align); in _mm_malloc()
47 if (posix_memalign(&__mallocedMemory, __align, __size)) in _mm_malloc()
H A D__clang_hip_runtime_wrapper.h55 extern "C" __device__ void *__hip_malloc(size_t __size);
57 static inline __device__ void *malloc(size_t __size) { in malloc() argument
58 return __hip_malloc(__size); in malloc()
62 static inline __device__ void *malloc(size_t __size) { in malloc() argument
/netbsd-src/external/gpl3/gcc/dist/libphobos/libdruntime/core/stdcpp/
H A Dstring_view.d79 this(const(T)[] str) @trusted { __data = str.ptr; __size = str.length; } in this()
86 size_type size() const @safe { return __size; } in size()
88 bool empty() const @safe { return __size == 0; } in empty()
93 const(T)[] as_array() const @trusted { return __data[0 .. __size]; } in as_array()
96 ref const(T) at(size_type i) const @trusted { return __data[0 .. __size][i]; } in at()
111 alias __size = _Mysize; in version() local
119 alias __size = _M_len; in version() local
124 size_type __size; in version() local
/netbsd-src/external/gpl3/gcc/dist/libsanitizer/asan/
H A Dasan_interceptors_memintrinsics.h54 uptr __size = (uptr)(size); \ in DECLARE_REAL()
56 if (__offset > __offset + __size) { \ in DECLARE_REAL()
58 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL()
60 if (!QuickCheckForUnpoisonedRegion(__offset, __size) && \ in DECLARE_REAL()
61 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL()
73 ReportGenericError(pc, bp, sp, __bad, isWrite, __size, 0, false);\ in DECLARE_REAL()
/netbsd-src/external/gpl3/gcc.old/dist/libsanitizer/asan/
H A Dasan_interceptors_memintrinsics.h53 uptr __size = (uptr)(size); \ in DECLARE_REAL()
55 if (__offset > __offset + __size) { \ in DECLARE_REAL()
57 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL()
59 if (!QuickCheckForUnpoisonedRegion(__offset, __size) && \ in DECLARE_REAL()
60 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL()
72 ReportGenericError(pc, bp, sp, __bad, isWrite, __size, 0, false);\ in DECLARE_REAL()
/netbsd-src/sys/external/bsd/compiler_rt/dist/lib/asan/
H A Dasan_interceptors_memintrinsics.h55 uptr __size = (uptr)(size); \ in DECLARE_REAL()
57 if (__offset > __offset + __size) { \ in DECLARE_REAL()
59 ReportStringFunctionSizeOverflow(__offset, __size, &stack); \ in DECLARE_REAL()
61 if (!QuickCheckForUnpoisonedRegion(__offset, __size) && \ in DECLARE_REAL()
62 (__bad = __asan_region_is_poisoned(__offset, __size))) { \ in DECLARE_REAL()
74 ReportGenericError(pc, bp, sp, __bad, isWrite, __size, 0, false);\ in DECLARE_REAL()
/netbsd-src/external/gpl3/gcc/dist/libphobos/libdruntime/core/sys/posix/sys/
H A Dtypes.d631 byte[__SIZEOF_PTHREAD_ATTR_T] __size; in version()
647 byte[__SIZEOF_PTHREAD_COND_T] __size; in version()
653 byte[__SIZEOF_PTHREAD_CONDATTR_T] __size; in version()
661 byte[__SIZEOF_PTHREAD_MUTEX_T] __size; in version()
667 byte[__SIZEOF_PTHREAD_MUTEXATTR_T] __size; in version()
675 byte[__SIZEOF_PTHREAD_RWLOCK_T] __size; in version()
681 byte[__SIZEOF_PTHREAD_RWLOCKATTR_T] __size; in version()
1175 byte[__SIZEOF_PTHREAD_ATTR_T] __size; in version()
1192 byte[__SIZEOF_PTHREAD_COND_T] __size; in version()
1198 byte[__SIZEOF_PTHREAD_CONDATTR_T] __size; in version()
[all …]
/netbsd-src/external/gpl3/gcc.old/dist/libssp/ssp/
H A Dunistd.h73 (char *__buf, size_t __size), getcwd);
76 getcwd (char *__buf, size_t __size) in getcwd() argument
78 if (__ssp_bos (__buf) != (size_t) -1 && __size > __ssp_bos (__buf)) in getcwd()
80 return __getcwd_alias (__buf, __size); in getcwd()
/netbsd-src/external/gpl3/gcc/dist/libssp/ssp/
H A Dunistd.h73 (char *__buf, size_t __size), getcwd);
76 getcwd (char *__buf, size_t __size) in getcwd() argument
78 if (__ssp_bos (__buf) != (size_t) -1 && __size > __ssp_bos (__buf)) in getcwd()
80 return __getcwd_alias (__buf, __size); in getcwd()

123456